@@ -41,10 +41,10 @@
 #include "unitmanager.h"
 #include "timecalcpart.h"
 #include "fixcalcpart.h"
+#include "portal.h"
 #include "materialcalcpart.h"
 #include "matcalcdialog.h"
 #include "stockmaterial.h"
-#include "stockmaterialman.h"
 #include "timecalcdialog.h"
 #include "fixcalcdialog.h"
 #include "stdsatzman.h"
@@ -697,9 +697,14 @@ void FlosTemplDialog::slNewMaterial( int matID, double amount )
 
     // TODO: Checken, ob der richtige Tab aktiv ist.
     // TODO: Check if the material is already in the calcpart (is this really needed??)
-    MaterialCalcPart *mc;
+    MaterialCalcPart *mc = new MaterialCalcPart(matID, 0, amount);
+    if( mc && ! mc->getMaterial() ) {
+        // the material is still unknown to the catalog because it was just entered
+        // in the material catalog
+        qDebug() << "ERR: MaterialCalcPart without Material!";
+        return;
+    }
 
-    mc = new MaterialCalcPart(matID, 0, amount);
     if( mc ) {
         mc->setProzentPlus(benefitValue());
 
@@ -816,14 +821,28 @@ void FlosTemplDialog::slSetNewText()
     }
 
     if( m_text ) {
-        QString t = m_text->toPlainText();
+        const QString t = Portal::textWrap( m_text->toPlainText(), 80, 5 );
+        const QStringList li = t.split(QLatin1Char('\n'));
+        QString longest;
+        for( const QString& p : li ) {
+            if( p.length() > longest.length() )
+                longest = p;
+        }
+        QFontMetrics fm(m_textDispFix->font());
+        int w = 10+fm.width(longest);
 
-        if( m_textDispTime)
+        if( m_textDispTime) {
             m_textDispTime->setText(t);
-        if( m_textDispFix)
+            m_textDispTime->setMinimumWidth(w);
+        }
+        if( m_textDispFix) {
             m_textDispFix->setText(t);
-        if( m_textDispMat)
+            m_textDispFix->setMinimumWidth(w);
+        }
+        if( m_textDispMat) {
             m_textDispMat->setText(t);
+            m_textDispMat->setMinimumWidth(w);
+        }
     }
 }
 /* END */
