@@ -80,7 +80,8 @@
 
 KraftView::KraftView(QWidget *parent) :
   KraftViewBase( parent ),
-  mHelpLabel( 0 ), mRememberAmount( -1 ), mModified( false )
+  mHelpLabel( 0 ), mRememberAmount( -1 ), mModified( false ),
+  mTaxBefore( -1 ), mDocPosEditorIndx( -1 )
 {
   setWindowTitle( i18n("Document" ) );
   setModal( false );
@@ -185,6 +186,9 @@ void KraftView::setupMappers()
   mModifiedMapper = new QSignalMapper( this );
   connect( mModifiedMapper,  SIGNAL( mapped( int ) ),
            this,  SLOT( slotPositionModified( int ) ) );
+  // block signals as long as the widget is built up.
+  // unblocking happens in redrawDocument()
+  mModifiedMapper->blockSignals(true);
 }
 
 void KraftView::setup( DocGuardedPtr doc )
@@ -200,6 +204,10 @@ void KraftView::setup( DocGuardedPtr doc )
   setupFooter();
   setWindowTitle( m_doc->docIdentifier() );
   slotSwitchToPage( KraftDoc::Header );
+
+  if( doc->isNew() ) {
+      mModified = true;
+  }
 }
 
 
@@ -240,13 +248,23 @@ void KraftView::setupDocHeaderView()
     m_headerEdit->m_cbType->clear();
     // m_headerEdit->m_cbType->insertStringList( DefaultProvider::self()->docTypes() );
     m_headerEdit->m_cbType->insertItems(-1, DocType::allLocalised() );
-
-    // if ( KraftSettings::self()->showDocumentLocale() ) {
-    //   m_headerEdit->mButtLang->show();
-    // } else {
-    // Hide the locale select button for now.
     m_headerEdit->mButtLang->hide();
-    // }
+
+    const QString predecessorDbId = m_doc->predecessorDbId();
+    bool predecIsVisible = false;
+    if( !predecessorDbId.isEmpty() ) {
+        DocGuardedPtr predecDoc = DocumentMan::self()->openDocument(predecessorDbId);
+        if( predecDoc ) {
+            const QString id = predecDoc->docIdentifier();
+            const QString link = QString("<a href=\"doc://show?id=%1\">%2</a>").arg(predecessorDbId).arg(id);
+            m_headerEdit->_labFollowup->setText( i18n("Successor of %1", link));
+            predecIsVisible = true;
+            connect( m_headerEdit->_labFollowup, SIGNAL(linkActivated(QString)),
+                     this, SLOT(slotLinkClicked(QString)));
+            delete predecDoc;
+        }
+    }
+    m_headerEdit->_labFollowup->setVisible(predecIsVisible);
 
     connect( m_headerEdit->m_cbType,  SIGNAL( activated( const QString& ) ),
              this, SLOT( slotDocTypeChanged( const QString& ) ) );
@@ -258,6 +276,16 @@ void KraftView::setupDocHeaderView()
     connect( edit, SIGNAL(pickAddressee()), this, SLOT(slotPickAddressee()) );
 }
 
+void KraftView::slotLinkClicked(const QString& link)
+{
+    QUrl u(link);
+    if( u.scheme() == "doc" && u.host() == "show" ) {
+        const QString ident = u.queryItemValue("id");
+        qDebug() << "Link clicked to open document " << ident;
+        emit openROView( ident );
+    }
+}
+
 void KraftView::setupItems()
 {
     KraftDocPositionsEdit *edit = new KraftDocPositionsEdit(this);
@@ -317,8 +345,9 @@ void KraftView::redrawDocument( )
     redrawDocPositions( );
     slotDocTypeChanged( doc->docType() );
     refreshPostCard();
+    mModifiedMapper->blockSignals(false);
 
-    mModified = false;
+   // mModified = false;
 }
 
 void KraftView::slotPickAddressee()
@@ -791,10 +820,10 @@ void KraftView::slotUnlockPosition( int pos )
 
 void KraftView::slotPositionModified( int )
 {
-  // qDebug () << "Modified Position " << pos << endl;
-  mModified = true;
+    // qDebug () << "Modified Position " << pos << endl;
+    mModified = true;
 
-  QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
+    QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
 }
 
 void KraftView::slotAddressFound(const QString& uid, const KContacts::Addressee& contact)
@@ -858,43 +887,18 @@ void KraftView::slotDocTypeChanged( const QString& newType )
 
   mAssistant->postCard()->slotShowPrices( docType.pricesVisible() );
   m_footerEdit->ui()->_taxGroup->setVisible( docType.pricesVisible() );
-  KraftDocPositionsEdit *w = dynamic_cast<KraftDocPositionsEdit*>(mViewStack->widget(mDocPosEditorIndx));
-  if(w) {
-      w->setDiscountButtonVisible(docType.pricesVisible());
+  if( mDocPosEditorIndx > -1 ) {
+      KraftDocPositionsEdit *w = dynamic_cast<KraftDocPositionsEdit*>(mViewStack->widget(mDocPosEditorIndx));
+      if(w) {
+          w->setDiscountButtonVisible(docType.pricesVisible());
+      }
   }
 }
 
 void KraftView::slotLanguageSettings()
 {
   // qDebug () << "Language Settings" << endl;
-#if 0
-  DocLocaleDialog dia( this );
-  QLocale *l = m_doc->locale();
-
-  // FIXME locale.
-  if ( m_doc ) {
-    dia.setLocale( l->country(), l->language() );
-
-    if ( dia.exec() == QDialog::Accepted  ) {
-      QString c = dia.locale().country();
-      if ( c != m_doc->locale()->country() ) {
-
-        KConfig *cfg = KGlobal::config().data();
-        m_doc->locale()->setCountry( c, cfg );
-        m_doc->locale()->setLanguage( dia.locale().language(), cfg );
-
-        PositionViewWidgetListIterator it( mPositionWidgetList );
-        while( it.hasNext() ) {
-          PositionViewWidget *w = it.next(); //  = 0;
-          w->setLocale( m_doc->locale() );
-          w->repaint();
-        }
-
-        refreshPostCard();
-      }
-    }
-  }
-#endif
+  // FIXME 
 }
 
 void KraftView::slotNewHeaderText( const QString& str )
@@ -1271,24 +1275,39 @@ void KraftView::slotShowCatalog( bool on )
 
 void KraftView::slotModifiedPositions()
 {
-  qDebug () << "Position Modified" << endl;
-  mModified = true;
+    // As long as the modified mapper is blocked, ignore this.
+    if( mModifiedMapper->signalsBlocked() ) {
+        return;
+    }
+
+    qDebug () << "Position Modified" << endl;
+    mModified = true;
 }
 
 void KraftView::slotModifiedHeader()
 {
-  // qDebug () << "Modified the header!" << endl;
-  mModified = true;
+    // qDebug () << "Modified the header!" << endl;
+    // As long as the modified mapper is blocked, ignore this.
+    if( mModifiedMapper->signalsBlocked() ) {
+        return;
+    }
 
-  QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
+    mModified = true;
+
+    QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
 }
 
 void KraftView::slotModifiedFooter()
 {
-  // qDebug () << "Modified the footer!" << endl;
-  mModified = true;
+    // qDebug () << "Modified the footer!" << endl;
+    // As long as the modified mapper is blocked, ignore this.
+    if( mModifiedMapper->signalsBlocked() ) {
+        return;
+    }
 
-  QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
+    mModified = true;
+
+    QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
 }
 
 QStringList KraftView::generateLetterHead( const QString& familyName, const QString& givenName )
