@@ -18,8 +18,11 @@
 #include <QWidget>
 #include <QLabel>
 #include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <QFormLayout>
 #include <QPushButton>
+#include <QCheckBox>
+#include <QWizard>
 
 #include <kcontacts/addressee.h>
 #include <QComboBox>
@@ -27,9 +30,9 @@
 #include <QDateEdit>
 #include <QDebug>
 #include <QTextEdit>
+#include <QPointer>
 
 #include <klocalizedstring.h>
-#include <kassistantdialog.h>
 
 #include "newdocassistant.h"
 #include "defaultprovider.h"
@@ -37,14 +40,16 @@
 #include "doctype.h"
 #include "kraftsettings.h"
 #include "addressselectorwidget.h"
+#include "documentman.h"
+
 
 CustomerSelectPage::CustomerSelectPage( QWidget *parent )
-  :QWidget( parent )
+  :QWizardPage ( parent )
 {
   QVBoxLayout *vbox = new QVBoxLayout;
-  parent->setLayout( vbox );
-//TODO PORT QT5   vbox->setSpacing( QDialog::spacingHint() );
-//TODO PORT QT5   vbox->setMargin( QDialog::marginHint() );
+  setLayout( vbox );
+
+  setTitle(i18n( "New Document Settings" ));
 
   QLabel *help = new QLabel;
   help->setText( i18n( "Please select a customer as addressee for the document. "
@@ -82,13 +87,13 @@ CustomerSelectPage:: ~CustomerSelectPage()
 // ###########################################################################
 
 DocDetailsPage::DocDetailsPage( QWidget *parent )
-  :mCustomerLabel( 0 )
+  : QWizardPage(parent),
+    _haveAddressSelect(true),
+    mCustomerLabel( nullptr )
 {
   QVBoxLayout *vbox = new QVBoxLayout;
-  parent->setLayout( vbox );
-
-//TODO PORT QT5   vbox->setSpacing( QDialog::spacingHint() );
-//TODO PORT QT5   vbox->setMargin( QDialog::marginHint() );
+  setLayout( vbox );
+  setTitle(i18n( "New Document Settings" ));
 
   QLabel *help = new QLabel;
   help->setTextFormat( Qt::RichText );
@@ -99,17 +104,12 @@ DocDetailsPage::DocDetailsPage( QWidget *parent )
   mCustomerLabel = new QLabel;
   mCustomerLabel->setFrameStyle( QFrame::Box + QFrame::Sunken );
   mCustomerLabel->setTextFormat( Qt::RichText );
-//TODO PORT QT5   mCustomerLabel->setMargin( QDialog::marginHint() );
   mCustomerLabel->setText( i18n( "Customer: Not yet selected!" ) );
   vbox->addWidget( mCustomerLabel );
 
   QFormLayout *grid = new QFormLayout;
-//TODO PORT QT5   grid->setSpacing( QDialog::marginHint() );
   vbox->addLayout( grid );
 
-//   QLabel *l = new QLabel( i18n( "Some Document Details: " ), vbox );
-//TODO PORT QT5 //  l->setMargin( QDialog::marginHint() );
-
   mTypeCombo = new QComboBox;
   mTypeCombo->insertItems( 0, DocType::allLocalised() );
   mTypeCombo->setCurrentIndex( mTypeCombo->findText( DefaultProvider::self()->docType() ));
@@ -122,9 +122,18 @@ DocDetailsPage::DocDetailsPage( QWidget *parent )
   mWhiteboardEdit = new QTextEdit;
   grid->addRow( i18n( "Whiteboard Content:" ), mWhiteboardEdit );
 
+  QHBoxLayout *hbox = new QHBoxLayout;
+  vbox->addLayout(hbox);
+  mKeepItemsCB = new QCheckBox( i18n("Copy document items from predecessor document"));
+  hbox->addWidget( mKeepItemsCB );
+  mSourceDocIdentsCombo = new QComboBox;
+  hbox->addWidget(mSourceDocIdentsCombo);
+  mSourceDocIdentsCombo->setVisible(false);
+
+  mKeepItemsCB->setChecked(true);
+  mKeepItemsCB->setVisible(false);
+
   vbox->addStretch( 1 );
-
-
 }
 
 DocDetailsPage::~DocDetailsPage()
@@ -132,12 +141,17 @@ DocDetailsPage::~DocDetailsPage()
 
 }
 
+void DocDetailsPage::setNoAddresses()
+{
+    _haveAddressSelect = false;
+}
+
 // ###########################################################################
 
 KraftWizard::KraftWizard(QWidget *parent, const char* name, bool modal )
-  :KAssistantDialog( parent ),
-   mCustomerPage( 0 ),
-   mCustomerBox( 0 ),
+  :QWizard( parent ),
+   mCustomerPage( nullptr ),
+   mCustomerBox( nullptr ),
    mParent( parent )
 {
   setObjectName( name );
@@ -152,21 +166,26 @@ KraftWizard::~KraftWizard()
 
 }
 
-void KraftWizard::init()
+void KraftWizard::init( bool haveAddressSelect, const QString& followUpDoc )
 {
     QScopedPointer<AddressProvider> addressProvider;
     addressProvider.reset(new AddressProvider);
 
-    setWindowTitle( i18n( "Document Creation Wizard" ) );
-    QWidget *w1 = new QWidget;
-    mDetailsPageItem = addPage( w1, i18n( "<h2>Document Details</h2>" ) );
-    mDetailsPage = new DocDetailsPage( w1 );
+    if( followUpDoc.isEmpty() ) {
+        setWindowTitle( i18n( "Create a new Kraft Document" ) );
+    } else {
+        setWindowTitle(followUpDoc);
+    }
 
-    if( addressProvider->backendUp() ) {
-        QWidget *w = new QWidget;
-        mCustomerPageItem = addPage( w, i18n( "<h2>Select an Addressee</h2>" ) );
+    mDetailsPage = new DocDetailsPage();
+    addPage(mDetailsPage);
+    // w1, QLatin1Literal("<h2>") +  + QLatin1Literal("</h2>") );
+
+    // only pick an addressee if the document is really new
+    if( addressProvider->backendUp() && haveAddressSelect ) {
+        mCustomerPage = new CustomerSelectPage( );
+        addPage( mCustomerPage); // w, QLatin1Literal("<h2>") + i18n( "Select an Addressee" ) + QLatin1Literal("</h2>") );
 
-        mCustomerPage = new CustomerSelectPage( w );
         mCustomerPage->setupAddresses();
         connect( mCustomerPage, SIGNAL( addresseeSelected(KContacts::Addressee)),
                  this,  SLOT( slotAddressee(KContacts::Addressee)));
@@ -181,7 +200,7 @@ void KraftWizard::done( int r )
     const QByteArray geo = saveGeometry().toBase64();
     KraftSettings::self()->setNewDocWizardGeometry(geo);
 
-    KAssistantDialog::done(r);
+    QWizard::done(r);
 }
 
 void KraftWizard::slotAddressee(const KContacts::Addressee& addressee)
@@ -210,14 +229,52 @@ QString KraftWizard::whiteboard() const
   return mDetailsPage->mWhiteboardEdit->toPlainText();
 }
 
-void KraftWizard::setDocIdentifier( const QString& ident )
+void KraftWizard::setDocToFollow( DocGuardedPtr sourceDoc)
 {
-  // we already know the customer, disable the customer select page.
-  setAppropriate( mCustomerPageItem, false );
+    if( !sourceDoc ) {
+        return;
+    }
+    DocGuardedPtr dPtr = sourceDoc;
 
-  if ( mDetailsPage->mCustomerLabel ) {
-    mDetailsPage->mCustomerLabel->setText( ident );
-  }
+    QString id = sourceDoc->docID().toString();
+    while( ! id.isEmpty() ) {
+        // store the id of the follower and clear id
+        const QString idT = dPtr->docIdentifier();
+        mDetailsPage->mSourceDocIdentsCombo->addItem(idT, id);
+        id = QString();
+
+        // remember the current dptr to be able to delete it soon
+        DocGuardedPtr oldDptr = dPtr;
+        dPtr =  DocumentMan::self()->openDocumentbyIdent( dPtr->predecessor() );
+        if( dPtr ) {
+            id = dPtr->docID().toString();
+        }
+        if( oldDptr != sourceDoc ) {
+            delete oldDptr;
+        }
+    }
+    if( mDetailsPage->mSourceDocIdentsCombo->count() > 0  ) {
+        mDetailsPage->mKeepItemsCB->setVisible(true);
+        mDetailsPage->mSourceDocIdentsCombo->setVisible(true);
+    }
+
+    // we already know the customer, disable the customer select page.
+     mDetailsPage->setNoAddresses();
+
+    if ( mDetailsPage->mCustomerLabel ) {
+        const QString followText = i18n("Followup Document for %1", sourceDoc->docIdentifier() );
+        mDetailsPage->mCustomerLabel->setText( followText );
+    }
+
+}
+
+QString KraftWizard::copyItemsFromPredecessor()
+{
+    QString re;
+    if( mDetailsPage->mKeepItemsCB->checkState() == Qt::Checked ) {
+        re = mDetailsPage->mSourceDocIdentsCombo->currentData().toString();
+    }
+    return re;
 }
 
 void KraftWizard::setAvailDocTypes( const QStringList& list )
