@@ -59,44 +59,93 @@
 // ################################################################################
 
 PrefsDialog::PrefsDialog( QWidget *parent)
-    : KPageDialog( parent )
+    :QDialog( parent )
 {
-  setFaceType( KPageDialog::List );
   setModal( true );
   setWindowTitle( i18n( "Configure Kraft" ) );
 
   QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
-  QWidget *mainWidget = new QWidget(this);
-  QVBoxLayout *mainLayout = new QVBoxLayout;
+  QHBoxLayout *mainLayout = new QHBoxLayout;
+
+  _navigationBar = new QListWidget(this);
+  _navigationBar->setViewMode(QListView::IconMode);
+  _navigationBar->setIconSize(QSize(96, 64));
+  _navigationBar->setMovement(QListView::Static);
+  //_navigationBar->setSpacing(6);
+  _navigationBar->setCurrentRow(0);
+  _navigationBar->setFixedWidth(195);
+
   setLayout(mainLayout);
-  mainLayout->addWidget(mainWidget);
+
+  QVBoxLayout *vbox = new QVBoxLayout;
+  _pagesWidget = new QStackedWidget(this);
+  vbox->addWidget( _pagesWidget );
+
+  vbox->addWidget( buttonBox );
+
+  mainLayout->addWidget(_navigationBar);
+
   QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
   okButton->setDefault(true);
   okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
   connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
   connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
-  mainLayout->addWidget(buttonBox);
+  mainLayout->addLayout(vbox);
   okButton->setDefault(true);
   setMinimumWidth(700);
 
-  docTab();
-  doctypeTab();
-  taxTab();
-  wagesTab();
-  unitsTab();
-  whoIsMeTab();
+  _maxNavBarTextWidth = 0;
+
+  addDialogPage( docTab(), QIcon::fromTheme( "edit-copy"), i18n( "Document Defaults" ));
+  addDialogPage( taxTab(), QIcon::fromTheme( "accessories-text-editor" ), i18n("Taxes"));
+  addDialogPage( doctypeTab(), QIcon::fromTheme( "folder-documents"), i18n( "Document Types" ));
+  mPrefsWages = new PrefsWages(this);
+  addDialogPage(mPrefsWages, QIcon::fromTheme( "help-donate" ), i18n( "Wages" ));
+  mPrefsUnits = new PrefsUnits(this);
+  addDialogPage(mPrefsUnits, QIcon::fromTheme( "chronometer" ), i18n("Units"));
+  addDialogPage( whoIsMeTab(), QIcon::fromTheme( "user-identity" ), i18n( "Own Identity" ));
 
   readConfig();
+
+
+  connect( _navigationBar, &QListWidget::itemClicked,
+           this, &PrefsDialog::changePage);
 }
 
-void PrefsDialog::taxTab()
+void PrefsDialog::changePage(QListWidgetItem *current)
+{
+  if (!current)
+      return;
+
+  int indx = _navigationBar->row(current);
+  _pagesWidget->setCurrentIndex(indx);
+}
+
+int PrefsDialog::addDialogPage( QWidget *w, const QIcon& icon, const QString& title)
+{
+    QListWidgetItem *listWidgetItem = new QListWidgetItem(_navigationBar);
+    listWidgetItem->setIcon(icon);
+    listWidgetItem->setText(title);
+    listWidgetItem->setTextAlignment(Qt::AlignCenter);
+    listWidgetItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+    listWidgetItem->setSizeHint( QSize(170, 100));
+
+    _navigationBar->addItem(listWidgetItem);
+
+    QWidget *w_with_title = new QWidget;
+    QVBoxLayout *layout = new QVBoxLayout;
+    layout->addWidget(new QLabel(QStringLiteral("<h1>")+title+QStringLiteral("</h1>")));
+    w_with_title->setLayout(layout);
+    layout->addWidget(w);
+    int indx = _pagesWidget->addWidget(w_with_title);
+
+    return indx;
+}
+
+QWidget* PrefsDialog::taxTab()
 {
   QWidget *topWidget = new QWidget;
 
-  KPageWidgetItem *topFrame = addPage( topWidget, i18n( "Taxes" ));
-
-  topFrame->setIcon(QIcon::fromTheme( "accessories-text-editor" ) );
-
   QVBoxLayout *vboxLay = new QVBoxLayout;
   // vboxLay->setSpacing( spacingHint() );
 
@@ -142,34 +191,14 @@ void PrefsDialog::taxTab()
 
   vboxLay->addLayout( butLay );
   topWidget->setLayout( vboxLay );
+
+  return topWidget;
 }
 
-void PrefsDialog::wagesTab()
-{
-    mPrefsWages = new PrefsWages(this);
-
-    KPageWidgetItem *topFrame = addPage( mPrefsWages, i18n( "Wages" ));
-
-    topFrame->setIcon(QIcon::fromTheme( "help-donate" ) );
-}
-
-void PrefsDialog::unitsTab()
-{
-    mPrefsUnits = new PrefsUnits(this);
-
-    KPageWidgetItem *topFrame = addPage( mPrefsUnits, i18n( "Units" ));
-
-    topFrame->setIcon(QIcon::fromTheme( "chronometer" ) );
-}
-
-void PrefsDialog::whoIsMeTab()
+QWidget* PrefsDialog::whoIsMeTab()
 {
   QWidget *topWidget = new QWidget;
 
-  KPageWidgetItem *topFrame = addPage( topWidget, i18n( "Own Identity" ));
-
-  topFrame->setIcon(QIcon::fromTheme( "user-identity" ) );
-
   QVBoxLayout *vboxLay = new QVBoxLayout;
 
   QLabel *label = new QLabel(i18n("Select the identity of the sending entity of documents. That's <b>your companies</b> address."));
@@ -215,6 +244,7 @@ void PrefsDialog::whoIsMeTab()
 
   topWidget->setLayout( vboxLay );
 
+  return topWidget;
 }
 
 void PrefsDialog::slotChangeIdentity()
@@ -255,14 +285,11 @@ void PrefsDialog::slotTaxSelected(QModelIndex)
   mDelTax->setEnabled( state );
 }
 
-void PrefsDialog::docTab()
+QWidget* PrefsDialog::docTab()
 {
   QLabel *label;
   QWidget *topWidget = new QWidget;
 
-  KPageWidgetItem *topFrame = addPage( topWidget, i18n( "Document Defaults" ) );
-  topFrame->setIcon(QIcon::fromTheme( "edit-copy" ) );
-
   QVBoxLayout *vboxLay = new QVBoxLayout;
   topWidget->setLayout( vboxLay );
   QGridLayout *topLayout = new QGridLayout;
@@ -281,19 +308,6 @@ void PrefsDialog::docTab()
   f->setFrameStyle( QFrame::HLine | QFrame::Sunken );
   vboxLay->addWidget( f );
 
-  // Localisation on document level
-  mCbDocLocale = new QCheckBox( i18n( "Enable &Localization on Document Level" ) );
-  mCbDocLocale->setToolTip( i18n( "Checking this enables language settings for each document."
-                                     "<br>Leave it unchecked to use the KDE Workspace default settings for "
-                                     "the document localisation." ) );
-  vboxLay->addWidget( mCbDocLocale );
-
-  vboxLay->addWidget( new QWidget );
-
-  f = new QLabel;
-  f->setFrameStyle( QFrame::HLine | QFrame::Sunken );
-  vboxLay->addWidget( f );
-
   QHBoxLayout *butLay = new QHBoxLayout;
   QLabel *l = new QLabel( i18n( "Default &Tax for Documents:" ) );
   butLay->addWidget( l );
@@ -312,13 +326,13 @@ void PrefsDialog::docTab()
   QWidget *spaceEater = new QWidget;
   spaceEater->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
   vboxLay->addWidget( spaceEater );
+
+    return topWidget;
 }
 
-void PrefsDialog::doctypeTab()
+QWidget* PrefsDialog::doctypeTab()
 {
   QWidget *topWidget = new QWidget;
-  KPageWidgetItem *topFrame = addPage( topWidget, i18n( "Document Types" ) );
-  topFrame->setIcon(QIcon::fromTheme( "folder-documents" ) );
 
   QVBoxLayout *vboxLay = new QVBoxLayout;
   topWidget->setLayout(vboxLay);
@@ -330,6 +344,7 @@ void PrefsDialog::doctypeTab()
   connect( mDocTypeEdit, SIGNAL( removedType( const QString& ) ),
            SLOT( slotDocTypeRemoved( const QString& ) ) );
 
+  return topWidget;
 }
 
 void PrefsDialog::slotDocTypeRemoved( const QString& type )
@@ -359,8 +374,6 @@ void PrefsDialog::slotDocTypeRemoved( const QString& type )
 
 void PrefsDialog::readConfig()
 {
-    mCbDocLocale->setChecked( KraftSettings::self()->showDocumentLocale() );
-
     QString t = KraftSettings::self()->doctype();
     if ( t.isEmpty() ) t = DefaultProvider::self()->docType();
 
@@ -409,8 +422,8 @@ void PrefsDialog::writeIdentity()
             f.close();
             qDebug() << "Saved own identity to " << file;
 
-            KraftSettings::self()->setUserName( QString::null );
-            KraftSettings::self()->setUserUid( QString::null );
+            KraftSettings::self()->setUserName( QString() );
+            KraftSettings::self()->setUserUid( QString() );
             KraftSettings::self()->save();
         }
     } else { /* AddressBook */
@@ -423,7 +436,6 @@ void PrefsDialog::writeIdentity()
 
 void PrefsDialog::writeConfig()
 {
-    KraftSettings::self()->setShowDocumentLocale( mCbDocLocale->isChecked() );
     KraftSettings::self()->setDoctype( mCbDocTypes->currentText() );
     KraftSettings::self()->setDefaultTaxType( 1+mCbDefaultTaxType->currentIndex() );
 
