@@ -142,8 +142,8 @@ QString ReportGenerator::findTemplate( const QString& type )
   return tmplFile;
 }
 
-#define TAG( THE_TAG )  QString( "%1").arg( THE_TAG )
-#define DICT( THE_DICT )  QString( "%1").arg( THE_DICT )
+#define TAG( THE_TAG )  QStringLiteral( THE_TAG )
+#define DICT( THE_DICT )  QStringLiteral( THE_DICT )
 
 void ReportGenerator::fillupTemplateFromArchive( const dbID& id )
 {
@@ -249,9 +249,9 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
   for ( it = posList.begin(); it != posList.end(); ++it ) {
     ArchDocPosition pos (*it);
     tmpl.createDictionary( "POSITIONS" );
-    tmpl.setValue( "POSITIONS", TAG( "POS_NUMBER" )
+    tmpl.setValue( DICT("POSITIONS"), TAG( "POS_NUMBER" )
                    , pos.posNumber() );
-    tmpl.setValue( "POSITIONS", "POS_TEXT",
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_TEXT"),
                    rmlString( pos.text(), QString( "%1text" ).arg( pos.kind().toLower() ) ) );
 
     // format the amount value of the item, do not show the precision if there is no fraction
@@ -267,11 +267,11 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
     // qDebug() << "**** " << num << " has precision " << prec;
     h = mArchDoc->locale()->toString( amount, 'f', prec );
 
-    tmpl.setValue( "POSITIONS", "POS_AMOUNT", h );
-    tmpl.setValue( "POSITIONS", "POS_UNIT", escapeTrml2pdfXML( pos.unit() ) );
-    tmpl.setValue( "POSITIONS", "POS_UNITPRICE", pos.unitPrice().toString( mArchDoc->locale() ) );
-    tmpl.setValue( "POSITIONS", "POS_TOTAL", pos.nettoPrice().toString( mArchDoc->locale() ) );
-    tmpl.setValue( "POSITIONS", "POS_KIND", pos.kind().toLower() );
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_AMOUNT"), h );
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_UNIT"), escapeTrml2pdfXML( pos.unit() ) );
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_UNITPRICE"), pos.unitPrice().toString( mArchDoc->locale() ) );
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_TOTAL"), pos.nettoPrice().toString( mArchDoc->locale() ) );
+    tmpl.setValue( DICT("POSITIONS"), TAG("POS_KIND"), pos.kind().toLower() );
 
     QString taxType;
 
@@ -299,7 +299,10 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
   }
   if ( specialPosCnt ) {
     tmpl.createDictionary( "SPECIAL_POS" );
-    tmpl.setValue( "SPECIAL_POS", "COUNT", QString::number( specialPosCnt ) );
+    tmpl.setValue( DICT("SPECIAL_POS"), TAG("COUNT"), QString::number( specialPosCnt ) );
+    tmpl.setValue( DICT("SPECIAL_POS"), TAG("LAB_SPECIAL_ITEMS"),
+                   i18n("Please note: This offer contains %1 alternative or demand positions, printed in italic font. These do not add to the overall sum.",
+                        QString::number( specialPosCnt ) ) );
   }
 
   /*
@@ -307,15 +310,26 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
    */
   if( individualTax ) {
     tmpl.createDictionary( "TAX_FREE_ITEMS" );
-    tmpl.setValue( "TAX_FREE_ITEMS", "COUNT", QString::number( taxFreeCnt ));
+    tmpl.setValue( DICT("TAX_FREE_ITEMS"), TAG("COUNT"), QString::number( taxFreeCnt ));
+    tmpl.setValue( DICT("TAX_FREE_ITEMS"), TAG( "LAB_TAX_FREE_ITEMS"),
+                   i18n("tax free items (%1 pcs.)", QString::number( taxFreeCnt )) );
 
     tmpl.createDictionary( "REDUCED_TAX_ITEMS" );
-    tmpl.setValue( "REDUCED_TAX_ITEMS", "COUNT", QString::number( reducedTaxCnt ));
-    tmpl.setValue( "REDUCED_TAX_ITEMS", "TAX", mArchDoc->locale()->toString( mArchDoc->reducedTax()) );
+    tmpl.setValue( DICT("REDUCED_TAX_ITEMS"), TAG("COUNT"), QString::number( reducedTaxCnt ));
+    tmpl.setValue( DICT("REDUCED_TAX_ITEMS"), TAG("TAX"), mArchDoc->locale()->toString( mArchDoc->reducedTax()) );
+    tmpl.setValue( DICT("REDUCED_TAX_ITEMS"), TAG("LAB_TAX_REDUCED_ITEMS"),
+                   i18n("items with reduced tax of %1% (%2 pcs.)",
+                        mArchDoc->locale()->toString( mArchDoc->reducedTax()),
+                        QString::number( reducedTaxCnt )) );
+
 
     tmpl.createDictionary( "FULL_TAX_ITEMS" );
-    tmpl.setValue( "FULL_TAX_ITEMS", "COUNT", QString::number( fullTaxCnt ));
-    tmpl.setValue( "FULL_TAX_ITEMS", "TAX", mArchDoc->locale()->toString( mArchDoc->tax()) );
+    tmpl.setValue( DICT("FULL_TAX_ITEMS"), TAG("COUNT"), QString::number( fullTaxCnt ));
+    tmpl.setValue( DICT("FULL_TAX_ITEMS"), TAG("TAX"), mArchDoc->locale()->toString( mArchDoc->tax()) );
+    tmpl.setValue( DICT("FULL_TAX_ITEMS"), TAG("LAB_TAX_FULL_ITEMS"),
+                   i18n("No label: items with full tax of %1% (%2 pcs.)",
+                        mArchDoc->locale()->toString( mArchDoc->tax()),
+                        QString::number( fullTaxCnt )) );
   }
 
   /* now replace stuff in the whole document */
@@ -339,19 +353,19 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
   // qDebug () << "Tax in archive document: " << h;
   if ( mArchDoc->reducedTaxSum().toLong() > 0 ) {
     tmpl.createDictionary( DICT( "SECTION_REDUCED_TAX" ) );
-    tmpl.setValue( "SECTION_REDUCED_TAX", TAG( "REDUCED_TAX_SUM" ),
+    tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX_SUM" ),
       mArchDoc->reducedTaxSum().toString( mArchDoc->locale() ) );
     h = mArchDoc->locale()->toString( mArchDoc->reducedTax() );
-    tmpl.setValue( "SECTION_REDUCED_TAX", TAG( "REDUCED_TAX" ), h );
-    tmpl.setValue( "SECTION_REDUCED_TAX", TAG( "REDUCED_TAX_LABEL" ), i18n( "reduced VAT" ) );
+    tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX" ), h );
+    tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX_LABEL" ), i18n( "reduced VAT" ) );
   }
   if ( mArchDoc->fullTaxSum().toLong() > 0 ) {
     tmpl.createDictionary( DICT( "SECTION_FULL_TAX" ) );
-    tmpl.setValue( "SECTION_FULL_TAX", TAG( "FULL_TAX_SUM" ),
+    tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX_SUM" ),
       mArchDoc->fullTaxSum().toString( mArchDoc->locale() ) );
     h = mArchDoc->locale()->toString( mArchDoc->tax() );
-    tmpl.setValue( "SECTION_FULL_TAX", TAG( "FULL_TAX" ), h );
-    tmpl.setValue( "SECTION_FULL_TAX", TAG( "FULL_TAX_LABEL" ), i18n( "VAT" ) );
+    tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX" ), h );
+    tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX_LABEL" ), i18n( "VAT" ) );
   }
 
   h = mArchDoc->locale()->toString( mArchDoc->tax() );
@@ -359,8 +373,21 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
 
   tmpl.setValue( TAG( "VATSUM" ), mArchDoc->taxSum().toString( mArchDoc->locale() ) );
 
-  // My own contact data
+  tmpl.setValue( TAG( "LAB_NO_SHORT"), i18nc("Sequence number printed on the document", "No.") );
+  tmpl.setValue( TAG( "LAB_ITEM"), i18nc("Document item printed on the document", "Item") );
+  tmpl.setValue( TAG( "LAB_QUANTITY_SHORT"), i18nc("Abbrev. of Quantity printed on the document", "Qty.") );
+  tmpl.setValue( TAG( "LAB_UNIT"), i18nc("Unit printed on the document", "Unit") );
+  tmpl.setValue( TAG( "LAB_PRICE"), i18nc("Price of an item printed on the document", "Price") );
+  tmpl.setValue( TAG( "LAB_SUM"), i18nc("Printed on the document", "Sum") );
+  tmpl.setValue( TAG( "LAB_NET"), i18nc("printed on the document", "Net") );
+  tmpl.setValue( TAG( "LAB_VAT"), i18nc("Printed on the document", "VAT") );
 
+  tmpl.setValue( TAG( "LAB_PHONE"), i18nc("Printed on the document", "Phone"));
+  tmpl.setValue( TAG( "LAB_FAX"), i18nc("Printed on the document", "FAX"));
+  tmpl.setValue( TAG( "LAB_MOBILE"), i18nc("Printed on the document", "Mobile"));
+  tmpl.setValue( TAG( "LAB_EMAIL"), i18nc("Printed on the document", "Email"));
+
+  // finalize the template
   const QString output = tmpl.expand();
   convertTemplate(output);
 }
@@ -437,70 +464,78 @@ QString ReportGenerator::rmlString( const QString& str, const QString& paraStyle
 
 QStringList ReportGenerator::findTrml2Pdf( )
 {
-  const QString rmlbinDefault = QString::fromLatin1( "trml2pdf" ); // FIXME: how to get the default value?
-  QString rmlbin = KraftSettings::self()->trml2PdfBinary();
-  // qDebug () << "### Start searching rml2pdf bin: " << rmlbin;
+    // define the default value to compare against, to see if there is a custom
+    // value in the settings file.
+    const QString rmlbinDefault = QStringLiteral( "trml2pdf" ); // FIXME: how to get the default value?
+    const QString rmlbin = KraftSettings::self()->trml2PdfBinary();
 
-  QStringList retList;
-  mHavePdfMerge = false;
+    // qDebug () << "### Start searching rml2pdf bin: " << rmlbin;
 
-  if ( rmlbinDefault == rmlbin  ) {
-    QString ermlpy = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kraft/tools/erml2pdf.py" );
-    // qDebug () << "Ermlpy: " << ermlpy;
-    if( ! ermlpy.isEmpty() ) {
-      // need the python interpreter
-      // First check for python2 in python3 times.
-      QString python = QStandardPaths::findExecutable(QLatin1String("python2"));
-      if( python.isEmpty() ) {
-        python = QStandardPaths::findExecutable(QLatin1String("python"));
-      }
-      if( python.isEmpty() ) {
-        qCritical() << "ERR: Unable to find python, thats a problem";
-      } else {
-        // qDebug () << "Using python: " << python;
-        retList << python;
-        retList << ermlpy;
-        mHavePdfMerge = true;
-      }
+    QStringList retList;
+    mHavePdfMerge = false;
+
+    if ( rmlbin != rmlbinDefault ) {
+        retList = rmlbin.split(' ', QString::SkipEmptyParts);
     } else {
-      // tool erml2pdf.py not found. Check in $KRAFT_HOME/tools
-      QString p = QString::fromUtf8(qgetenv("KRAFT_HOME"));
-      if( !p.isEmpty() ) {
-          p += QLatin1String("/tools/erml2pdf.py");
-          // qDebug () << "Found erml2pdf from KRAFT_HOME: " << p;
-          if( QFile::exists( p ) ) {
-              retList << "python";
-              retList << p;
-              mHavePdfMerge = true;
-          }
-      } else {
-          // tool erml2pdf.py not found. Try trml2pdf_kraft.sh for legacy reasons
-          QString trml2pdf = QStandardPaths::findExecutable(QLatin1String("trml2pdf_kraft.sh"));
-          if( trml2pdf.isEmpty() ) {
-              // qDebug () << "Could not find trml2pdf_kraft.sh";
-          } else {
-              // qDebug () << "Found trml2pdf: " << trml2pdf;
-              retList << trml2pdf;
-              mHavePdfMerge = true;
-          }
-      }
+        // The value in the config is not, as it is still the same as the default
+        // read from either KRAFT_HOME or search in the system.
+        QString p = QString::fromUtf8(qgetenv("KRAFT_HOME"));
+        if( !p.isEmpty() ) {
+            p += QLatin1String("/tools/erml2pdf.py");
+            // qDebug () << "Found erml2pdf from KRAFT_HOME: " << p;
+            if( QFile::exists( p ) ) {
+                retList << "python";
+                retList << p;
+                mHavePdfMerge = true;
+            }
+        } else {
+            const QString ermlpy = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kraft/tools/erml2pdf.py" );
+            // qDebug () << "Ermlpy: " << ermlpy;
+            if( ! ermlpy.isEmpty() ) {
+                // need the python interpreter
+                // First check for python2 in python3 times.
+                QString python = QStandardPaths::findExecutable(QLatin1String("python2"));
+                if( python.isEmpty() ) {
+                    python = QStandardPaths::findExecutable(QLatin1String("python"));
+                }
+                if( python.isEmpty() ) {
+                    qCritical() << "ERR: Unable to find python, thats a problem";
+                } else {
+                    // qDebug () << "Using python: " << python;
+                    retList << python;
+                    retList << ermlpy;
+                    mHavePdfMerge = true;
+                }
+            }
+        }
+        if (retList.isEmpty() ){
+            // tool erml2pdf.py not found. Try trml2pdf_kraft.sh for legacy reasons
+            QString trml2pdf = QStandardPaths::findExecutable(QLatin1String("trml2pdf_kraft.sh"));
+            if( trml2pdf.isEmpty() ) {
+                // qDebug () << "Could not find trml2pdf_kraft.sh";
+            } else {
+                // qDebug () << "Found trml2pdf: " << trml2pdf;
+                retList << trml2pdf;
+                mHavePdfMerge = true;
+            }
+        }
+
+
+        if ( ! mHavePdfMerge ) {
+            QString trml2pdf = QStandardPaths::findExecutable(QLatin1String("trml2pdf"));
+            if( trml2pdf.isEmpty() ) {
+                // qDebug () << "trml2pdf is also empty, we can not convert rml. Debug!";
+            } else {
+                // qDebug () << "trml2pdf found here: " << trml2pdf;
+                retList << trml2pdf;
+            }
+        }
+    }
+    if ( retList.isEmpty() ) {
+        qDebug () << "PDF conversion script not found!";
     }
 
-    if ( ! mHavePdfMerge ) {
-      QString trml2pdf = QStandardPaths::findExecutable(QLatin1String("trml2pdf"));
-      if( trml2pdf.isEmpty() ) {
-        // qDebug () << "trml2pdf is also empty, we can not convert rml. Debug!";
-      } else {
-        // qDebug () << "trml2pdf found here: " << trml2pdf;
-        retList << trml2pdf;
-      }
-    }
-  }
-  if ( retList.isEmpty() ) {
-    // qDebug () << "We have not found the script!";
-  }
-
-  return retList;
+    return retList;
 }
 
 
@@ -614,15 +649,18 @@ void ReportGenerator::trml2pdfFinished( int exitCode, QProcess::ExitStatus stat)
     if( mFile.isOpen() ) {
         mFile.close();
     }
-    Q_UNUSED(stat);
+    Q_UNUSED(stat)
 
     // qDebug () << "PDF Creation Process finished with status " << exitStatus;
     // qDebug () << "Wrote bytes to the output file: " << mOutputSize;
     if ( exitCode == 0 ) {
-        emit pdfAvailable( mFile.fileName() );
-        if( mProcess) {
-            const QString rmlFile = mProcess->arguments().last(); // the file name of the temp rmlfile
-            QFile::remove(rmlFile); // remove the rmlFile
+        QFileInfo fi(mFile.fileName());
+        if( fi.exists() ) {
+            emit pdfAvailable( mFile.fileName() );
+            if( mProcess) {
+                const QString rmlFile = mProcess->arguments().last(); // the file name of the temp rmlfile
+                QFile::remove(rmlFile); // remove the rmlFile
+            }
         }
     } else {
         if( mErrors.contains(QLatin1String("No module named Reportlab"))) {
