@@ -515,7 +515,8 @@ void SetupAssistant::slotCurrentPageChanged( int currId )
                 filename = defaultSqliteFilename();
                 setField("SqliteStorageFile", filename);
             }
-            if( !KraftDB::self()->dbConnect( QLatin1String("QSQLITE"), filename ) ) {
+            if( !KraftDB::self()->dbConnect( QLatin1String("QSQLITE"), filename,
+                                             QString(), QString(), QString()) ) {
                 setField("CreateDbStatusText", i18n("<p>Can't open your database file, check the permissions and such."));
             }
         }
@@ -624,12 +625,11 @@ void SetupAssistant::startDatabaseUpdate()
 
     while ( currentVer < KraftDB::self()->requiredSchemaVersion() ) {
         ++currentVer;
-        const QString migrateFilename = QString( "%1_dbmigrate.sql" ).arg( currentVer );
         // qDebug () << "######### Reading " << migrateFilename;
-        mUpgradeDbPage->slotSetStatusText( i18n("Reading upgrade command file %1", migrateFilename ) );
-        SqlCommandList cmds = KraftDB::self()->parseCommandFile( migrateFilename );
+        const SqlCommandList cmds = KraftDB::self()->parseCommandFile( currentVer );
+        commandLists.append(cmds);
         overallCmdCount += cmds.count();
-        commandLists << cmds;
+        qDebug() << "Appending" << cmds.count() << "commands for version" << currentVer;
     }
     mUpgradeDbPage->slotSetOverallCount( overallCmdCount );
 
@@ -644,16 +644,16 @@ void SetupAssistant::startDatabaseUpdate()
     bool errors = false;
 
     currentVer = KraftDB::self()->currentSchemaVersion();
-    foreach( SqlCommandList cmds, commandLists ) {
+    for( SqlCommandList cmdList : commandLists ) {
         currentVer++;
-        int goodCmds = KraftDB::self()->processSqlCommands( cmds );
+        int goodCmds = KraftDB::self()->processSqlCommands( cmdList );
         doneOverallCmds += goodCmds;
-        if( goodCmds != cmds.count() ) {
-            // qDebug () << "Only performned " << goodCmds << " out of " << cmds.count();
+        if( goodCmds != cmdList.count() ) {
+            qDebug () << "Only performned " << goodCmds << " out of " << cmdList.count();
             errors = true;
             break;
         } else {
-            // qDebug () << goodCmds << " commands performed well!";
+            qDebug () << goodCmds << " commands performed well, version is " << currentVer << ", listversion:" << cmdList.number();
             KraftDB::self()->setSchemaVersion( QString::number( currentVer ));
         }
     }
@@ -661,8 +661,8 @@ void SetupAssistant::startDatabaseUpdate()
     if( errors ) {
         mUpgradeDbPage->slotSetStatusText( i18n("The Upgrade failed!") );;
     } else {
-        mUpgradeDbPage->slotSetStatusText( i18n("The Upgrade succeeded, the current schema version is %1!")
-                                           .arg( KraftDB::self()->requiredSchemaVersion() ) );;
+        mUpgradeDbPage->slotSetStatusText( i18n("The Upgrade succeeded, the current schema version is %1!",
+                                           KraftDB::self()->requiredSchemaVersion() ) );;
     }
 
     disconnect( mUpgradeDbPage, SLOT( slotSetStatusText( const QString& )));
@@ -720,6 +720,11 @@ void SetupAssistant::startDatabaseCreation()
 
         mCreateDbPage->setStatusText( i18n( "Process database fillup commands..." ) );
         creates = KraftDB::self()->processSqlCommands( fillCommands );
+
+        if( creates != fillCommands.count() ) {
+            qDebug() << "Could not execute all fill commands";
+            res = false;
+        }
     }
 
     if( res ) {
@@ -742,7 +747,8 @@ bool SetupAssistant::handleSqLiteDetails()
 
     mSqlBackendDriver = mDbSelectPage->selectedDriver();
     // qDebug () << "The database driver is " << mSqlBackendDriver;
-    bool re = KraftDB::self()->dbConnect( mSqlBackendDriver, file );
+    bool re = KraftDB::self()->dbConnect( mSqlBackendDriver, file,
+                                          QString(), QString(), QString() );
 
     return re;
 }
@@ -784,7 +790,17 @@ bool SetupAssistant::init( Mode mode )
             // qDebug () << "A standard KDE Platform 4.x database config file is there.";
         }
 
-        if( KraftDB::self()->dbConnect() )  { // try to connect with default values
+        const QString dbDriver = DatabaseSettings::self()->dbDriver().toUpper();
+        QString dbName = DatabaseSettings::self()->dbDatabaseName();
+        if( dbDriver == QLatin1String("QSQLITE")) {
+            dbName = DatabaseSettings::self()->dbFile();
+        }
+
+        if( KraftDB::self()->dbConnect( dbDriver,
+                                        dbName,
+                                        DatabaseSettings::self()->dbUser(),
+                                        DatabaseSettings::self()->dbServerName(),
+                                        DatabaseSettings::self()->dbPassword()) )  { // try to connect with default values
             // qDebug () << "The database can be opened!";
             if( KraftDB::self()->databaseExists() ) {
                 // qDebug () << "The database exists.";
@@ -795,7 +811,7 @@ bool SetupAssistant::init( Mode mode )
                     configOrigin += QLatin1String(" ") + i18n("The database schema version is too low. "
                                                               "It will be updated.");
                 } else if( KraftDB::self()->currentSchemaVersion() > KraftDB::self()->requiredSchemaVersion() ) {
-                    configOrigin += QLatin1Char(' ') + i18n("The current database schema version si too high. Leaving untouched! ");
+                    configOrigin += QLatin1Char(' ') + i18n("The current database schema version is too high. Leaving untouched! ");
                     // qDebug () << "Database Schema is OK. Nothing to do for StartupAssistant";
                 }
             } else {
@@ -809,7 +825,7 @@ bool SetupAssistant::init( Mode mode )
             // unable to connect to the database at all
             startDialog = true;
             hitNextClosing = false;
-            text = i18n( "<p>Kraft could not connect to the configured database.<p>" );
+            text = i18n( "<p>Kraft failed to connect to the configured database.</p>" );
             if( KraftDB::self()->qtDriver().toUpper() == "QMYSQL" ) {
                 text += i18n( "<p>Please check the database server setup and restart Kraft to connect." );
             } else {
