@@ -41,18 +41,15 @@ public:
                  double perPack, Geld pIn, Geld pOut );
   ~StockMaterial();
 
-  QString name() const;
-  void setName( const QString& );
-
+#if 0
+  // currently not used.
   QString description() const;
   void setDescription( const QString& );
+#endif
 
   double getAmountPerPack();
   void setAmountPerPack( double am );
 
-  Einheit getUnit();
-  void setUnit(const Einheit& );
-
   int getID();
   void setID( int );
 
@@ -83,13 +80,12 @@ protected:
   void saveChapterId();
 
 private:
-  QString m_name;
-  QString m_descr;
+  // QString m_descr;
   int     m_chapter;
 
   // per package:
   double  m_amount;
-  Einheit m_unit;
+  int     m_unit;
   int     m_dbid;
 
   // FIXME: introduce supplier list
