@@ -18,8 +18,7 @@
 // include files for Qt
 
 // include files for KDE
-#include <klocale.h>
-#include <kdebug.h>
+#include <QDebug>
 
 #include "templatesaverbase.h"
 
@@ -34,7 +33,7 @@ bool TemplateSaverBase::saveTemplate(FloskelTemplate*)
     return false;
 }
 
-void TemplateSaverBase::saveTemplateChapter( FloskelTemplate *flos )
+void TemplateSaverBase::saveTemplateChapter( FloskelTemplate* )
 {
   // do nothing
 }
