@@ -16,9 +16,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <QtSql>
+#include <QSqlQuery>
 #include <QDebug>
 #include <QMenu>
+#include <QHeaderView>
+#include <QByteArray>
 
 #include <klocalizedstring.h>
 
@@ -34,6 +36,7 @@
 #include "timecalcpart.h"
 #include "docposition.h"
 #include "defaultprovider.h"
+#include "kraftsettings.h"
 
 TemplKatalogListView::TemplKatalogListView(QWidget *w)
     : KatalogListView(w),
@@ -46,6 +49,9 @@ TemplKatalogListView::TemplKatalogListView(QWidget *w)
 
   setHeaderLabels(labels);
 
+  QByteArray headerState = QByteArray::fromBase64( KraftSettings::self()->templateCatViewHeader().toAscii() );
+  header()->restoreState(headerState);
+
   contextMenu()->setTitle( i18n("Template Catalog"));
 }
 
@@ -119,10 +125,13 @@ void TemplKatalogListView::slFreshupItem( QTreeWidgetItem *item, FloskelTemplate
   if( !(item && tmpl) ) return;
 
   Geld g     = tmpl->unitPrice();
-  QString ck = tmpl->calcKindString();
-  QString t  = Portal::textWrap(tmpl->getText(), 60);
+  const QString ck = tmpl->calcKindString();
+  const QString t  = Portal::textWrap(tmpl->getText(), 72, 4);
 
   item->setText( 0, t );
+  if( t.endsWith(QLatin1Literal("..."))) {
+      item->setToolTip(0, Portal::textWrap(tmpl->getText(), 72, 22));
+  }
   QString h;
   h = QString( "%1 / %2" ).arg( g.toString( catalog()->locale() ) )
       .arg( tmpl->unit().einheitSingular() );
@@ -276,3 +285,10 @@ void TemplKatalogListView::slotUpdateSequence()
   KatalogListView::slotUpdateSequence();
 }
 
+void TemplKatalogListView::saveState()
+{
+    const QByteArray state = this->header()->saveState();
+
+    KraftSettings::self()->setTemplateCatViewHeader(state.toBase64());
+    KraftSettings::self()->save();
+}
